.. InfiniSDK documentation master file, created by
   sphinx-quickstart on Tue Sep  3 15:07:25 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

InfiniSDK User's Guide
======================

Overview
--------

InfiniSDK is Infinidat's Official Python SDK for interacting with Infinidat storage products. It provides a clean interface for creating, deleting, querying and manipulating API objects.

Compatibility
-------------

InfiniSDK is designed to be compatible with the currently shipped version of InfiniBox, as well as prior releases which are under active support. Compatibility with future version is guaranteed only to a limited extent, especially regarding new or changed functionality.

Contents:

.. toctree::
   :maxdepth: 2

   getting_started
   querying
   efficient_querying
   system_object
   capacities
   pools
   volumes
   filesystems
   mappings
   snapshots
   snapshot_policies
   cons_groups
   users
   system_configuration
   networking
   replication
   metadata
   events
   components
   qos
   smb_users_and_groups
   active_directory_domains
   extending
   cookbook
   faq
   api
   advanced_usage
   hooks
   smb_server_capabilities
   nfs_server_capabilities


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

